![hippo_logo](https://github.com/mwinokan/HIPPO/blob/main/logos/hippo_logo-05.png?raw=true)

HIPPO
=====

> 🦛 Hit Interaction Profiling for Procurement Optimisation

HIPPO is still in alpha development and is not recommended for public use.
